==> jc-unilever-client-0.1.412-sources.jar: com/xforceplus/ultraman/app/jcunilever/controller/BlobFilesFeignApi.java <==
package com.xforceplus.ultraman.app.jcunilever.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2023-06-07
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jcunilever.entity.BlobFiles;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-unilever")
public interface BlobFilesFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/blobFiles/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param blobFiles ${table.comment}
   * @return R
   */
  @PostMapping("/blobFiles/add")
  public R save(@RequestBody BlobFiles blobFiles);

  /**
   * 修改${table.comment}
   * @param blobFiles ${table.comment}
   * @return R
   */
  @PostMapping("/blobFiles/update")
  public R updateById(@RequestBody BlobFiles blobFiles);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/blobFiles/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-unilever-client-0.1.669-sources.jar: com/xforceplus/ultraman/app/jcunilever/controller/BlobFilesFeignApi.java <==
package com.xforceplus.ultraman.app.jcunilever.controller;


/**
 * OTC业务feign客户端
 *
 * @author ultraman
 * @date 2023-11-29
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jcunilever.entity.BlobFiles;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-unilever")
public interface BlobFilesFeignApi {

  /**
   * 通过id查询OTC业务
   * @param  id
   * @return R
   */
  @GetMapping("/blobFiles/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增OTC业务
   * @param blobFiles OTC业务
   * @return R
   */
  @PostMapping("/blobFiles/add")
  public R save(@RequestBody BlobFiles blobFiles);

  /**
   * 修改OTC业务
   * @param blobFiles OTC业务
   * @return R
   */
  @PostMapping("/blobFiles/update")
  public R updateById(@RequestBody BlobFiles blobFiles);

  /**
   * 通过id删除OTC业务
   * @param  id
   * @return R
   */
  @DeleteMapping("/blobFiles/del/{id}" )
  public R removeById(@PathVariable Long id);

}
